@@ -9,5 +9,8 @@ from .dishwasher import *
 from .laundry import *
 from .advantium import *
 from .water_filter import *
+from .water_softener import *
 from .ac import *
-from .hood import *
\ No newline at end of file
+from .hood import *
+from .ice_maker import *
+from .microwave import *
\ No newline at end of file
