@@ -36,3 +36,5 @@ class ErdCodeClass(enum.IntFlag):
     WATERFILTER_SENSOR = auto()
     AC_SENSOR = auto()
     HOOD_SENSOR = auto()
+    OIM_SENSOR = auto()
+    WATERSOFTENER_SENSOR = auto()
\ No newline at end of file
