@@ -180,10 +180,34 @@ class ErdCode(enum.Enum):
 
     # Microwave
     MICROWAVE_RECIPE_STATUS = "0x5300"
+    MICROWAVE_COOK_SETTING = "0x5c00" 
+    MICROWAVE_AVAILABLE_MODES = "0x5c01"
+    MICROWAVE_UNKNOWN_5C02 = "0x5c02"
+    MICROWAVE_UNKNOWN_5C03 = "0x5c03"
+    MICROWAVE_UNKNOWN_5C04 = "0x5c04"
+    MICROWAVE_UNKNOWN_5C05 = "0x5c05"
+    MICROWAVE_UNKNOWN_5C0A = "0x5c0a"
+    MICROWAVE_UNKNOWN_5C0B = "0x5c0b"
+    MICROWAVE_UNKNOWN_5C0C = "0x5c0c"
+    MICROWAVE_UNKNOWN_5C0D = "0x5c0d"
+    MICROWAVE_UNKNOWN_5C0E = "0x5c0e"
+    MICROWAVE_UNKNOWN_5C0F = "0x5c0f"
+    MICROWAVE_UNKNOWN_5C10 = "0x5c10"
+    MICROWAVE_STATE = "0x5c11"
     MICROWAVE_UNKNOWN_5C12 = "0x5c12"
+    MICROWAVE_UNKNOWN_5C13 = "0x5c13"
     MICROWAVE_REMOTE_ENABLE = "0x5c14"
+    MICROWAVE_COOK_TIMER = "0x5c15"
+    MICROWAVE_UNKNOWN_5C16 = "0x5c16"
+    MICROWAVE_UNKNOWN_5C17 = "0x5c17"
     MICROWAVE_UNKNOWN_5C18 = "0x5c18"
-    # Lots more in 0x5Cxx
+    MICROWAVE_KITCHEN_TIMER = "0x5c19"
+    MICROWAVE_COOK_TIME_SETTING_MODIFICATION = "0x5c1a"
+    MICROWAVE_UNKNOWN_5C1B = "0x5c1b"
+    MICROWAVE_UNKNOWN_5C1E = "0x5c1e"
+    MICROWAVE_UNKNOWN_5C20 = "0x5c20"
+    MICROWAVE_UNKNOWN_5C2C = "0x5c2c"
+    MICROWAVE_UNKNOWN_5C2E = "0x5c2e"
 
     # Hood
     HOOD_TIMER_AVAILABILITY = "0x500f"
@@ -224,6 +248,15 @@ class ErdCode(enum.Enum):
     WH_FILTER_LEAK_VALIDITY = "0x116e"
     WH_FILTER_LIFE_REMAINING = "0x1164"
 
+    # Water Softener
+    WH_SOFTENER_ERROR_CODE = "0x8004"
+    WH_SOFTENER_UNKNOWN8005 = "0x8005"
+    WH_SOFTENER_LOW_SALT = "0x8007"
+    WH_SOFTENER_UNKNOWN800D = "0x800d"
+    WH_SOFTENER_UNKNOWN800E = "0x800e"
+    WH_SOFTENER_SHUTOFF_VALVE_STATE = "0x8033"
+    WH_SOFTENER_SHUTOFF_VALVE_CONTROL = "0x8034"
+
     # AIR CONDITIONER
     AC_TARGET_TEMPERATURE = "0x7003"
     AC_FAN_SETTING = "0x7a00"
@@ -243,4 +276,13 @@ class ErdCode(enum.Enum):
     SAC_TARGET_TEMPERATURE_RANGE = "0x7b06"
     SAC_AUTO_SWING_MODE = "0x7b07"
 
+    #Ice Maker
+    OIM_STATUS = "0x9100"
+    OIM_LIGHT_LEVEL = "0x9101"
+    OIM_UNKNOWN9102 = "0x9102"
+    OIM_FILTER_STATUS = "0x9104"
+    OIM_UNKNOWN9106 = "0x9106"
+    OIM_POWER = "0x9107"
+    OIM_UNKNOWN9108 = "0x9108"
+
 ErdCodeType = Union[ErdCode, str]
