@@ -13,13 +13,13 @@ class ErdApplianceType(enum.Enum):
     OVEN = "07"
     ELECTRIC_RANGE = "08"
     GAS_RANGE = "09"
-    AIR_CONDITIONER = "0a"
-    ELECTRIC_COOKTOP = "0b"
+    AIR_CONDITIONER = "0A"
+    ELECTRIC_COOKTOP = "0B"
     COOKTOP = "11"
-    PIZZA_OVEN = "0c"
-    GAS_COOKTOP = "0d"
-    SPLIT_AIR_CONDITIONER = "0e"
-    HOOD = "0f"
+    PIZZA_OVEN = "0C"
+    GAS_COOKTOP = "0D"
+    SPLIT_AIR_CONDITIONER = "0E"
+    HOOD = "0F"
     POE_WATER_FILTER = "10"
     WATER_SOFTENER = "15"
     PORTABLE_AIR_CONDITIONER = "16"
@@ -27,5 +27,5 @@ class ErdApplianceType(enum.Enum):
     ZONELINE = "14"
     DELIVERY_BOX = "12"
     CAFE_COFFEE_MAKER = "1A"
-    OPAL_ICE_MAKER = "1b"
-    DEHUMIDIFIER = "1d"
+    OPAL_ICE_MAKER = "1B"
+    DEHUMIDIFIER = "1D"
