@@ -12,7 +12,7 @@ class ErdDishwasherDoorStatus(enum.Enum):
     def boolify(self) -> Optional[bool]:
         if self == ErdDishwasherDoorStatus.NA:
             return None
-        return self.value == ErdDishwasherDoorStatus.OPEN
+        return self == ErdDishwasherDoorStatus.OPEN
 
     def stringify(self, **kwargs) -> Optional[str]:
         if self == ErdDishwasherDoorStatus.NA:
